import sys
from io import StringIO
from unittest.mock import patch

from nose.tools import eq_


def test_stdout():
    test_args = ["moban", "-t", "{{'tests' is directory}}"]
    with patch.object(sys, "argv", test_args):
        with patch("sys.stdout", new_callable=StringIO) as fake_stdout:
            from moban.main import main

            main()
            eq_(fake_stdout.getvalue(), "True\n")



# flake8: noqa
from lml.loader import scan_plugins_regex
from moban_ansible._version import __author__, __version__

ANSIBLE_LIBRARIES = "^moban_ansible_.+$"
ANSIBLE_EXTENSIONS = [
    "moban_ansible.tests.files",
]


scan_plugins_regex(ANSIBLE_LIBRARIES, "moban", None, ANSIBLE_EXTENSIONS)
